from setuptools import setup, find_packages
setup(
    name="lpar_activation",
    version="0.0.1",
    packages=find_packages(),
    install_requires=["pytest==8.3.4",
                      "gitdb==4.0.12",
                      "GitPython==3.1.44",
                      "pytest==8.3.4",
                      "setuptools==75.8.0",
                      ],
)
